Learn R Programming

opart (version 2019.1.0)

opart_gaussian: compute the optimal changepoint model for a vector of real-valued data and a non-negative real-valued penalty, given the square loss (to minimize) / gaussian likelihood (to maximize)

Description

compute the optimal changepoint model for a vector of real-valued data and a non-negative real-valued penalty, given the square loss (to minimize) / gaussian likelihood (to maximize)

Usage

opart_gaussian(data, penalty)

Arguments

data

A numerical vector for which the changepoint model is to be computed

penalty

A non-negative real number indicating penalty parameter

Value

A vector of the optimal cost values and a vector of the optimal segment ends

Examples

Run this code
# NOT RUN {
data(neuroblastoma, package="neuroblastoma")
selectedData <- subset(neuroblastoma$profiles, profile.id=="1" & chromosome=="1")
opart::opart_gaussian(data=selectedData$logratio, penalty=1)
# }

Run the code above in your browser using DataLab