Learn R Programming

opart (version 2019.1.0)

opart_poisson: compute the optimal changepoint model for a vector of real-valued data and a non-negative real-valued penalty, given the poisson loss (to minimize) / log likelihood (to maximize)

Description

compute the optimal changepoint model for a vector of real-valued data and a non-negative real-valued penalty, given the poisson loss (to minimize) / log likelihood (to maximize)

Usage

opart_poisson(data, penalty)

Arguments

data

A list of numbers for which the changepoint model is to be computed

penalty

A non-negative real number indicating penalty parameter

Value

An error status code with a pointer to the optimal cost values and a pointer to the optimal segment ends

Examples

Run this code
# NOT RUN {
sample_data <- rpois(100, 10.5)
opart::opart_poisson(data=sample_data, penalty=1)
# }

Run the code above in your browser using DataLab