opart_poisson: compute the optimal changepoint model for a vector of real-valued data
and a non-negative real-valued penalty,
given the poisson loss (to minimize) / log likelihood (to maximize)
Description
compute the optimal changepoint model for a vector of real-valued data
and a non-negative real-valued penalty,
given the poisson loss (to minimize) / log likelihood (to maximize)
Usage
opart_poisson(data, penalty)
Arguments
data
A list of numbers for which the changepoint model is to be computed
penalty
A non-negative real number indicating penalty parameter
Value
An error status code with a pointer to the optimal cost values and a pointer to the optimal segment ends